<?xml version='1.0' encoding='utf-8' ?>
<!DOCTYPE xsl:stylesheet [
<!ENTITY ldquo '&#x201C;' >
<!ENTITY rdquo '&#x201D;' >
<!ENTITY nbsp  '&#xA0;'   >
]>
<!-- ============================================================= -->
<!--  MODULE:    EXTREME.XSL                                       -->
<!--  VERSION:   1.5                                               -->
<!--  DATE:      March 2006                                        -->
<!--                                                               -->
<!-- ============================================================= -->

<!-- ============================================================= -->
<!-- SYSTEM:     EXTREME XML TO WEB                                -->
<!--             Mulberry Technologies, Inc.                       -->
<!--                                                               -->
<!-- PURPOSE:    Transform incoming valid XML documents from       -->
<!--             the extreme-author.dtd to html format             -->
<!--                                                               -->
<!--             Input file contains one document that represents  -->
<!--             a paper in the Extreme conference proceedings.    -->
<!--             Alternatively, the input may be a "paper stub"    -->
<!--             (a metadata placeholder in lieu of a full paper). -->
<!--             A paper may reference external files for such     -->
<!--             things as figures and graphics.                   -->
<!--                                                               -->
<!--                                                               -->
<!-- CREATED FOR:GCA Extreme 2001 Conference Proceedings web site  -->
<!-- CREATED BY: MULBERRY TECHNOLOGIES, INC.                       -->
<!--                                                               -->
<!-- ORIGINAL CREATION DATE:                                       -->
<!--             March 23, 2001                                    -->
<!--                                                               -->
<!-- CREATED BY: Wendell Piez
                 Paul Rosenberg                                    -->
<!--                                                               -->
<!-- UNDERLYING DTDs:                                              -->
<!--             extremepaper.xml.dtd                              -->
<!--                                                               -->
<!-- DEPENDENCIES:

  EXTERNAL STYLESHEET MODULES:
  table.xsl
    DocBook/OASIS -> html table conversion (thanks to Norman Walsh)

  Otherwise this stylesheet should have no dependencies and should
  be useful on a stand-alone basis (for batch or in-browser use)

-->

<!-- ============================================================= -->


<!-- ============================================================= -->
<!--               VERSION HISTORY                                 -->
<!-- ============================================================= -->
<!--

     CHANGE LOG

 6.  CLEANED UP REARRANGEMENT                       v1.5  20060309
     General scouring to make this stylesheet a more reasonable
     standalone stylesheet
 5.  REARRANGED ARCHITECTURE                        v1.4  20040914
     Rearranged the entire suite of stylesheets so that
     this (main) module could be called on its own.
 4.  CLEANUP AND MINOR TWEAKS                       v1.3  20030812
     Including replacing tables with proper divs, thereby
     moving much formatting code out to the CSS layer.
 3.  MODIFIED FOR EXTREME FINAL DESIGN              v1.2  20010911
 2.  MODIFIED FOR EXTREME PRE-FINAL                 v1.1  20010809
 1.  ORIGINAL VERSION                               v1.0  20010423
                                                                   -->

<!-- ============================================================= -->
<!--                    XSL STYLESHEET INVOCATION                  -->
<!-- ============================================================= -->


<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:math="http://www.w3.org/1998/Math/MathML"
                exclude-result-prefixes="math">

<xsl:import href="table.xsl"/>
<!-- import the Norman Walsh OASIS (DocBook) table stylesheet      -->

<!-- GET THE NAME OF THE LIST OF ALL PAPER FILES                   -->

<xsl:strip-space elements="paper front author address bio
   abstract keywords body section subsec1 subsec2 subsec3
   rear acknowl bibliog bibitem lquote note figure caption
   randlist seqlist li deflist def.item def acronym.grp ftnote
   table thead tgroup row"/>

<xsl:preserve-space elements="sgml.block verbatim"/>

<xsl:output method="html" indent="yes" encoding="utf-8" />

<xsl:param name="rootdir" select="'.'"/>

<xsl:param name="cssfile" select="'extreme.css'"/>

<xsl:param name="conference" select="'Extreme Markup Languages'"/>

<xsl:variable name="secnumbers" select="paper/@secnumbers"/>
<!-- the value should be an integer. 0 (the default) means
     no section numbering. An empty node set results if
     no DTD is available to provide a default; the tests
     (below) will account for this. -->

<xsl:variable name="footnotes" select="//ftnote"/>

<!-- set parameters for Norman Walsh's table stylesheet: -->
  <xsl:variable name="default.table.width" select="'85%'"/>

  <xsl:variable name="saxon.extensions" select="0"/>
  <!-- running without extensions -->

  <xsl:variable name="saxon.tablecolumns" select="0"/>
  
<!-- [end parameters for table.xsl] -->

  
  <xsl:param name="paperlabel" select="'extreme-paper'"/>
  <!-- override from the calling stylesheet -->

  <!-- A 'clean reading' rendition has only a simple
       masthead and no link or navbar
       but a calling stylesheet can provide them -->
  
  <xsl:template name="masthead">
    <table class="masthead" width="100%">
      <tr>
        <td align="right">
          <xsl:value-of select="$conference"/>
        </td>
      </tr>
    </table>
  </xsl:template>
  
  
  <xsl:template name="indexlinkbar"/>
  
  <xsl:template name="navbar"/>
  
  <xsl:template name="logocenter"/>

<!-- START GENERATING THE HTML PAGE                                -->
<xsl:template match="/">
  <html>
    <head>
      <title>
        <xsl:apply-templates select="/paper/front/title | /paperstub/title" mode="plaintext"/>
      </title>
      <base name="{$paperlabel}"/>
      <xsl:if test="$cssfile">
        <link rel="stylesheet" href="{concat($rootdir, '/',$cssfile)}" type="text/css"/>
      </xsl:if>
    </head>
    <body>

    <xsl:call-template name="indexlinkbar"/>

    <xsl:call-template name="masthead"/>

    <xsl:call-template name="navbar"/>

    <xsl:apply-templates/>

    <xsl:call-template name="indexlinkbar"/>

    <xsl:call-template name="logocenter"/>
    
    </body>
  </html>
</xsl:template>

<xsl:template match="paper">
  <xsl:apply-templates select="front|body"/>
  <xsl:call-template name="footnotes"/>
  <xsl:apply-templates select="rear"/>
  <hr/>
  <xsl:apply-templates select="front/title" mode="rear" />
  <xsl:apply-templates select="front/author" mode="rear" />
  <hr/>
</xsl:template>

<xsl:template match="paperstub">
  <xsl:apply-templates select="title | subt | author"/>
  <h3><i>This paper is not represented in the conference proceedings.</i></h3>
</xsl:template>
  
<xsl:template match="front">
  <xsl:apply-templates select="title|subt"/>
  <xsl:apply-templates select="author"/>
  <xsl:apply-templates select="keywords"/>
  <xsl:apply-templates select="abstract"/>
  <xsl:apply-templates select="copyright"/>
</xsl:template>

<xsl:template match="front/title | paperstub/title">
  <h1>
    <xsl:if test="../@id">
      <a name="../@id"/>
    </xsl:if>
    <xsl:apply-templates/>
  </h1>
</xsl:template>

<xsl:template match="front/subt | paperstub/subt">
  <xsl:if test="normalize-space()">
  <!-- catch authors who place an empty subt -->
    <h2>
      <xsl:apply-templates/>
    </h2>
  </xsl:if>
</xsl:template>

<xsl:template match="front/title" mode="rear">
  <p class="footertitle">
    <xsl:if test="../@id">
      <a name="../@id"/>
    </xsl:if>
    <xsl:apply-templates/>
  </p>
</xsl:template>

<xsl:template match="subt"/>

<xsl:template match="author">
  <xsl:if test="preceding-sibling::author">
    <br class="br"/>
  </xsl:if>
  <address>
    <xsl:apply-templates select="fname"/>
    <xsl:text> </xsl:text>
    <xsl:apply-templates select="surname"/>
    <xsl:text> [</xsl:text>
    <xsl:apply-templates select="jobtitle"/>
    <xsl:if test="jobtitle">
      <xsl:text>; </xsl:text>
    </xsl:if>
    <xsl:apply-templates select="address"/>
    <xsl:text>]</xsl:text>
  </address>
</xsl:template>

<xsl:template match="author" mode="rear">
  <!--
  <xsl:if test="preceding-sibling::author">
    <br/>
  </xsl:if> -->
  <address>
    <xsl:apply-templates select="fname|surname" mode="rear"/>
    <xsl:text>[</xsl:text>
    <xsl:apply-templates select="jobtitle|address/affil|address/subaffil" mode="rear"/>
    <xsl:text>]</xsl:text>
    <xsl:apply-templates select="address/email" mode="rear"/>
  </address>
</xsl:template>

<xsl:template match="jobtitle|affil" mode="rear">
  <xsl:apply-templates/>
  <xsl:if test="following-sibling::address/affil or following-sibling::subaffil">
    <xsl:text>, </xsl:text>
  </xsl:if>
</xsl:template>

<xsl:template match="fname|surname" mode="rear">
  <xsl:apply-templates/>
  <xsl:text> </xsl:text>
</xsl:template>

<xsl:template match="email" mode="rear">
  <br class="br"/>
  <a href="mailto:{.}" class="mailto">
    <xsl:apply-templates/>
  </a>
</xsl:template>

<xsl:template match="jobtitle">
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="address">
  <xsl:apply-templates select="affil|subaffil"/>
<!--  <xsl:apply-templates select="aline|city|state|province|cntry|postcode|phone|fax|email|web"/> -->
</xsl:template>

<xsl:template match="affil">
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="aline|city|cntry|province">
  <xsl:text>, </xsl:text>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="subaffil">
  <xsl:text>, </xsl:text>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="state|postcode">
  <xsl:text> </xsl:text>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="phone">
  <br class="br"/><xsl:text>tel: </xsl:text>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="fax">
  <br class="br"/><xsl:text>fax: </xsl:text>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="address/email">
  <br class="br"/>
  <a href="mailto:{.}">
    <xsl:apply-templates/>
  </a>
</xsl:template>

<xsl:template match="address/web">
  <br class="br"/>
  <a href="{.}" target="_blank">
    <xsl:apply-templates/>
  </a>
</xsl:template>

<xsl:template match="abstract"/>

<xsl:template match="keywords"/>

<xsl:template match="copyright">
  <h4><i>
    <xsl:apply-templates/>
  </i></h4>
</xsl:template>

<!-- BODY CONTENT ELEMENTS                                         -->

<xsl:template match="section|subsec1|subsec2|subsec3">
  <div class="{local-name()}">
    <xsl:apply-templates/>
  </div>
</xsl:template>

<xsl:template name="marksectitle">
  <xsl:variable name="numstring">
    <xsl:number level="multiple" format="1.1.1.1" count="section|subsec1|subsec2|subsec3"/>
  </xsl:variable>
  <a>
    <xsl:attribute name="name">
      <xsl:choose>
        <xsl:when test="../@id">
          <xsl:value-of select="../@id"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="concat('t', $numstring)"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:attribute>
  </a>
  <xsl:if test="$secnumbers = 1">
    <xsl:value-of select="concat($numstring, ' ')"/>
  </xsl:if>
</xsl:template>

<xsl:template match="section/title">
  <h2>
    <xsl:call-template name="marksectitle"/>
    <xsl:apply-templates/>
  </h2>
</xsl:template>

<xsl:template match="subsec1/title">
  <h3>
    <xsl:call-template name="marksectitle"/>
    <xsl:apply-templates/>
  </h3>
</xsl:template>

<xsl:template match="subsec2/title">
  <h4>
    <xsl:call-template name="marksectitle"/>
    <xsl:apply-templates/>
  </h4>
</xsl:template>

<xsl:template match="subsec3/title">
  <h5>
    <xsl:call-template name="marksectitle"/>
    <xsl:apply-templates/>
  </h5>
</xsl:template>

<xsl:template match="para">
  <p>
    <xsl:apply-templates/>
  </p>
</xsl:template>

<xsl:template match="note">
  <div class="note">
    <h5>NOTE: </h5>
    <xsl:apply-templates/>
  </div>
</xsl:template>

<xsl:template match="graphic">
  <xsl:apply-templates select="." mode="figure"/>
</xsl:template>

<xsl:template match="figure">
  <div class="figure">
    <xsl:if test="@id">
      <a name="{@id}"/>
    </xsl:if>
    <h5>Figure <xsl:number count="figure" level="any"/>
      <xsl:if test="title">
        <xsl:text>: </xsl:text>
      </xsl:if>
      <xsl:apply-templates select="title"/>
    </h5>
    <xsl:apply-templates select="graphic|verbatim|para" mode="figure"/>
    <xsl:apply-templates select="caption"/>
  </div>
</xsl:template>

<xsl:template match="caption">
  <div style="font-size:85%">
    <xsl:apply-templates/>
  </div>
</xsl:template>

<xsl:template match="verbatim" mode="figure">
  <pre>
    <xsl:apply-templates/>
  </pre>
</xsl:template>

<xsl:template match="para" mode="figure">
  <p>
    <xsl:apply-templates/>
  </p>
</xsl:template>

<xsl:template match="graphic" mode="figure">
  <xsl:variable name="given-filename">
    <xsl:choose>
      <xsl:when test="normalize-space(@file)">
        <xsl:value-of select="@file"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="unparsed-entity-uri(@figname)"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  <xsl:variable name="filename">
    <xsl:call-template name="trimURI">
      <xsl:with-param name="URIstring" select="$given-filename"/>
    </xsl:call-template>
  </xsl:variable>
  <xsl:choose>
    <xsl:when test="$filename">
      <img src="{$filename}" border="0">
        <xsl:if test="@scale and number(translate(@scale,'%','')) &lt; 100">
          <xsl:attribute name="width">100%</xsl:attribute>
        </xsl:if>
      </img>
      <h5>[Link to <a href="{$filename}" target="{$filename}">open this graphic in a separate page</a>]</h5>
    </xsl:when>
    <xsl:otherwise>
      <h5>
        <i>(Please declare graphic entity)</i>
      </h5>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="lquote">
  <div class="lquote">
    <xsl:apply-templates/>
  </div>
</xsl:template>

<xsl:template name="trimURI">
  <!-- trims a URI to just what follows the final '/' character
       (i.e. should be just a relative path to a file in the same subdirectory) -->
  <xsl:param name="URIstring" select="''"/>
  <xsl:choose>
    <xsl:when test="contains($URIstring, '/')">
      <xsl:call-template name="trimURI">
        <xsl:with-param name="URIstring" select="substring-after($URIstring, '/')"/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <xsl:value-of select="$URIstring"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="randlist">
  <xsl:choose>
    <xsl:when test="@style='simple'">
      <dl>
        <xsl:apply-templates/>
      </dl>
    </xsl:when>
    <xsl:otherwise>
      <ul>
        <xsl:if test="@style='dashed'">
          <!-- dashed lists get squares ... too bad -->
          <xsl:attribute name="type">
            <xsl:text>square</xsl:text>
          </xsl:attribute>
        </xsl:if>
        <xsl:apply-templates/>
      </ul>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="seqlist">
  <ol>
    <xsl:attribute name="type">
      <xsl:choose>
        <xsl:when test="ualpha">A</xsl:when>
        <xsl:when test="uroman">I</xsl:when>
        <xsl:when test="lalpha">a</xsl:when>
        <xsl:when test="lroman">i</xsl:when>
        <xsl:otherwise>1</xsl:otherwise>
      </xsl:choose>
    </xsl:attribute>
    <xsl:apply-templates/>
  </ol>
</xsl:template>

<xsl:template match="li">
  <xsl:choose>
    <xsl:when test="parent::randlist[@style='simple']">
      <dd>
        <xsl:apply-templates/>
      </dd>
    </xsl:when>
    <xsl:otherwise>
      <li>
        <xsl:apply-templates/>
      </li>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="li/para">
  <xsl:apply-templates/>
  <xsl:if test="following-sibling::*">
    <br class="br"/>
  </xsl:if>
</xsl:template>

<xsl:template match="deflist">
  <xsl:apply-templates select="title"/>
    <table border="0" cellpadding="8" class="deflist">
      <xsl:if test="term.heading|def.heading">
        <tr>
          <th>
            <xsl:apply-templates select="term.heading"/>
          </th>
          <th>
            <xsl:apply-templates select="def.heading"/>
          </th>
        </tr>
      </xsl:if>
      <xsl:apply-templates select="def.item"/>
    </table>
</xsl:template>

<xsl:template match="deflist/title">
  <h4>
    <xsl:apply-templates/>
  </h4>
</xsl:template>

<xsl:template match="def.item">
  <tr>
    <xsl:apply-templates/>
  </tr>
</xsl:template>

<xsl:template match="def.term|def">
  <td valign="top">
    <xsl:apply-templates/>
  </td>
</xsl:template>

<!-- Inline elements -->

<xsl:template match="expansion">
  <!-- we don't need to match acronym.grp or acronym, just
       pass them through -->
  <xsl:text> [</xsl:text>
  <xsl:apply-templates/>
  <xsl:text>]</xsl:text>
</xsl:template>

<xsl:key name="by-id" match="*" use="@id"/>

  <xsl:template match="bibref">
    <b>
      <span style="font-size:85%">
        <a href="#{@refloc}" name="from{@refloc}">
          <xsl:text>[</xsl:text>
          <xsl:value-of select="key('by-id',@refloc)/bib"/>
          <xsl:text>]</xsl:text>
        </a>
      </span>
    </b>
  </xsl:template>

<xsl:template match="inline.graphic">
  <xsl:variable name="given-filename">
    <xsl:choose>
      <xsl:when test="normalize-space(@file)">
        <xsl:value-of select="@file"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="unparsed-entity-uri(@figname)"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  <xsl:variable name="filename">
    <xsl:call-template name="trimURI">
      <xsl:with-param name="URIstring" select="$given-filename"/>
    </xsl:call-template>
  </xsl:variable>
  <xsl:choose>
    <xsl:when test="$filename">
      <img src="{$filename}" border="0"/>
    </xsl:when>
    <xsl:otherwise>
      <b>
        <i>(Please declare graphic entity)</i>
      </b>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="cit">
 <i>
   <xsl:apply-templates/>
 </i>
</xsl:template>

<xsl:template match="fnref">
  <xsl:variable name="ftnote" select="key('by-id',@refloc)"/>
  <xsl:variable name="noteno">
    <xsl:for-each select="$ftnote">
      <xsl:number level="any"/>
    </xsl:for-each>
  </xsl:variable>
  <sup>
    <span class="highlight">
      <a href="#to{generate-id($ftnote)}">
        <xsl:value-of select="$noteno"/>
      </a>
    </span>
  </sup>
</xsl:template>

<xsl:template match="ftnote">
  <xsl:variable name="noteno">
    <xsl:number level="any"/>
  </xsl:variable>
  <sup>
    <span class="highlight">
      <a href="#to{generate-id()}" name="from{generate-id()}">
          <xsl:value-of select="$noteno"/>
        </a>
    </span>
  </sup>
</xsl:template>

<xsl:template match="ftnote" mode="notes">
  <xsl:variable name="noteno">
    <xsl:number level="any" format="1."/>
  </xsl:variable>
  <tr>
    <td valign="top" width="10%" align="right">
    <a href="#from{generate-id()}" name="to{generate-id()}">
      <b><xsl:value-of select="$noteno"/></b>
    </a>
    </td>
    <td>
      <xsl:apply-templates/>
    </td>
  </tr>
</xsl:template>

<xsl:template match="sgml | code">
  <tt class="code">
    <xsl:apply-templates/>
  </tt>
</xsl:template>

<xsl:template match="sgml.block|verbatim|codeblock">
  <div>
    <xsl:if test="not(ancestor::table)">
      <xsl:attribute name="class">codeblock</xsl:attribute>
    </xsl:if>
    <pre>
      <xsl:apply-templates/>
    </pre>
  </div>
</xsl:template>

<xsl:template match="figure/verbatim|figure/sgml.block">
  <pre>
    <xsl:apply-templates/>
  </pre>
</xsl:template>

<xsl:template match="xref">
  <a href="#{@refloc}">
    <xsl:apply-templates select="key('by-id',@refloc)" mode="xreftext">
      <xsl:with-param name="type" select="@type"/>
    </xsl:apply-templates>
  </a>
</xsl:template>

<xsl:template match="section|subsec1|subsec2|subsec3" mode="xreftext">
  <xsl:param name="type" select="'title'"/>
  <xsl:choose>
    <xsl:when test="$type='title' or not(/paper/@secnumbers='1')">
      <xsl:text>&ldquo;</xsl:text>
        <xsl:apply-templates select="title" mode="inline"/>
      <xsl:text>&rdquo;</xsl:text>
    </xsl:when>
    <xsl:otherwise>
      <!-- xsl:text>Section </xsl:text -->
      <xsl:number level="multiple" format="1.1.1.1" count="section|subsec1|subsec2|subsec3"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="figure" mode="xreftext">
  <xsl:param name="type" select="'title'"/>
  <xsl:choose>
    <xsl:when test="$type='title'">
      <xsl:text>&ldquo;</xsl:text>
      <xsl:apply-templates select="title" mode="inline"/>
      <xsl:text>&rdquo;</xsl:text>
    </xsl:when>
    <xsl:otherwise>
      <!-- xsl:text>Figure </xsl:text -->
      <xsl:number level="any"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="highlight[@style='bold']">
  <b>
    <xsl:apply-templates/>
  </b>
</xsl:template>

<xsl:template match="highlight[@style='ital']">
  <i>
    <xsl:apply-templates/>
  </i>
</xsl:template>

<xsl:template match="highlight[@style='under']">
  <u>
    <xsl:apply-templates/>
  </u>
</xsl:template>

<xsl:template match="highlight[@style='roman']">
  <span style="font-style:normal; font-weight:normal">
    <xsl:apply-templates/>
  </span>
</xsl:template>

<xsl:template match="highlight[@style='bital']">
  <i>
    <b>
      <xsl:apply-templates/>
    </b>
  </i>
</xsl:template>

<xsl:template match="sub">
  <sub>
    <xsl:apply-templates/>
  </sub>
</xsl:template>

<xsl:template match="super">
  <sup>
    <xsl:apply-templates/>
  </sup>
</xsl:template>

<!-- inline mode allows processing of titles and such in line -->

<xsl:template match="title" mode="inline">
  <xsl:apply-templates/>
</xsl:template>

<!-- Back matter and bibliography elements -->

<xsl:template name="footnotes">
  <xsl:if test="$footnotes">
    <h3 class="footnotes">Notes</h3>
    <table class="footnotes">
      <xsl:apply-templates select="$footnotes" mode="notes"/>
    </table>
  </xsl:if>
</xsl:template>

<xsl:template match="rear">
  <hr/>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="acknowl">
  <h3><i>
    <xsl:text>Acknowledgments</xsl:text>
  </i></h3>
  <xsl:apply-templates/>
  <hr/>
</xsl:template>

<xsl:template match="bibliog">
  <h3><i>
    <xsl:text>Bibliography</xsl:text>
  </i></h3>
  <xsl:apply-templates>
    <xsl:sort select="bib"/>
  </xsl:apply-templates>
  <hr/>
</xsl:template>

<xsl:template match="bibitem">
  <p>
    <xsl:apply-templates/>
  </p>
</xsl:template>

<xsl:template match="bib">
  <b><a name="{../@id}">
    <xsl:if test="//bibref/@refloc=../@id">
      <xsl:attribute name="href">
        <xsl:value-of select="concat('#from', ../@id)"/>
      </xsl:attribute>
    </xsl:if>
    <xsl:text>[</xsl:text>
    <xsl:apply-templates/>
    <xsl:text>] </xsl:text>
  </a></b>
</xsl:template>

<xsl:template match="pub">
  <xsl:text> </xsl:text>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="web">
  <xsl:variable name="link">
    <xsl:if test="not(contains(.,':'))">
      <xsl:text>http://</xsl:text>
    </xsl:if>
    <xsl:value-of select="normalize-space(.)"/>
  </xsl:variable>
  <a href="{$link}" target="_blank">
    <xsl:apply-templates/>
  </a>
</xsl:template>

<xsl:template match="math:*">
  <span style="font-family: 'Lucida Sans Unicode'">
    <xsl:copy-of select="."/>
  </span>
</xsl:template>
  
  <xsl:template match="lb" mode="plaintext">
    <xsl:text> </xsl:text>
  </xsl:template>
  
  <xsl:template match="ftnote" mode="plaintext"/>
  
</xsl:stylesheet>

<!-- ==============  END EXTREME.XSL STYLESHEET  ================  -->
