<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  version="2.0">
  
  <!-- An XSLT 2.0 stylesheet that generates, for an XML document, a
       profile of its tagging.
    
    This could be done in XSLT 1.0, but 2.0 is faster and easier
    
    Creates plain-text output. A fancy version for production use
      might create formatted (HTML or PDF) output
  
  -->
  
  <xsl:output method="text"/>

  <xsl:template name="header">
    <xsl:value-of select="document-uri(/)"/>
    <xsl:text>&#xA;</xsl:text>
    <xsl:for-each select="/paper/front/author">
      <xsl:value-of select="normalize-space(string-join((fname|surname), ' '))"/>
      <xsl:if test="position() != last()">
        <xsl:choose>
          <xsl:when test="position() + 1 = last()"> and </xsl:when>
          <xsl:otherwise>, </xsl:otherwise>
        </xsl:choose>
      </xsl:if>
    </xsl:for-each>
    <xsl:text>&#xA;</xsl:text>
    <xsl:apply-templates select="/paper/front/title" mode="plain"/>
    <xsl:text>&#xA;--- </xsl:text>
  </xsl:template>
  
  <xsl:template match="/" name="extreme-uri-warnings">
    <xsl:call-template name="header"/>
    <xsl:apply-templates select="//text() except //web//text()" mode="uri-warnings"/>
    <!-- we're not looking at URIs inside <web>, where they're expected -->
    <xsl:text>&#xA;=====&#xA;</xsl:text>
  </xsl:template>

  <xsl:template match="text()" mode="uri-warnings">
    <!-- generates a warning for *any* 'word' (whitespace-delimited substring)
           which contains a ":/" as being a possible URI -->
    <xsl:variable name="current" select="."/>
    <xsl:variable name="snippets" select="tokenize(normalize-space(),' ')"/>
    <xsl:for-each select="$snippets[contains(.,':/')]">
      <xsl:text>&#xA;Warning, possible URI found: </xsl:text>
      <xsl:value-of select="."/>
      <xsl:text>&#xA;  in path </xsl:text>
      <xsl:apply-templates select="$current" mode="make-path"/>
      <xsl:text>&#xA;</xsl:text>
    </xsl:for-each>
  </xsl:template>  
  
  <xsl:include href="xpath-support.xsl"/>

</xsl:stylesheet>
